==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/KafkaSpecFluent.java <==
package io.strimzi.api.kafka.model;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface KafkaSpecFluent<A extends KafkaSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildKafka instead.
 * @return The buildable object.
 */
@Deprecated public KafkaClusterSpec getKafka();
    public KafkaClusterSpec buildKafka();
    public A withKafka(KafkaClusterSpec kafka);
    public Boolean hasKafka();
    public KafkaSpecFluent.KafkaNested<A> withNewKafka();
    public KafkaSpecFluent.KafkaNested<A> withNewKafkaLike(KafkaClusterSpec item);
    public KafkaSpecFluent.KafkaNested<A> editKafka();
    public KafkaSpecFluent.KafkaNested<A> editOrNewKafka();
    public KafkaSpecFluent.KafkaNested<A> editOrNewKafkaLike(KafkaClusterSpec item);
    
/**
 * This method has been deprecated, please use method buildZookeeper instead.
 * @return The buildable object.
 */
@Deprecated public ZookeeperClusterSpec getZookeeper();
    public ZookeeperClusterSpec buildZookeeper();
    public A withZookeeper(ZookeeperClusterSpec zookeeper);
    public Boolean hasZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> withNewZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> withNewZookeeperLike(ZookeeperClusterSpec item);
    public KafkaSpecFluent.ZookeeperNested<A> editZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> editOrNewZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> editOrNewZookeeperLike(ZookeeperClusterSpec item);
    
/**
 * This method has been deprecated, please use method buildTopicOperator instead.
 * @return The buildable object.
 */
@Deprecated public TopicOperatorSpec getTopicOperator();
    public TopicOperatorSpec buildTopicOperator();
    public A withTopicOperator(TopicOperatorSpec topicOperator);
    public Boolean hasTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> withNewTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> withNewTopicOperatorLike(TopicOperatorSpec item);
    public KafkaSpecFluent.TopicOperatorNested<A> editTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> editOrNewTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> editOrNewTopicOperatorLike(TopicOperatorSpec item);
    
/**
 * This method has been deprecated, please use method buildEntityOperator instead.
 * @return The buildable object.
 */
@Deprecated public EntityOperatorSpec getEntityOperator();
    public EntityOperatorSpec buildEntityOperator();
    public A withEntityOperator(EntityOperatorSpec entityOperator);
    public Boolean hasEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> withNewEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> withNewEntityOperatorLike(EntityOperatorSpec item);
    public KafkaSpecFluent.EntityOperatorNested<A> editEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> editOrNewEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> editOrNewEntityOperatorLike(EntityOperatorSpec item);
    
/**
 * This method has been deprecated, please use method buildClusterCa instead.
 * @return The buildable object.
 */
@Deprecated public CertificateAuthority getClusterCa();
    public CertificateAuthority buildClusterCa();
    public A withClusterCa(CertificateAuthority clusterCa);
    public Boolean hasClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> withNewClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> withNewClusterCaLike(CertificateAuthority item);
    public KafkaSpecFluent.ClusterCaNested<A> editClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> editOrNewClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> editOrNewClusterCaLike(CertificateAuthority item);
    
/**
 * This method has been deprecated, please use method buildKafkaExporter instead.
 * @return The buildable object.
 */
@Deprecated public KafkaExporterSpec getKafkaExporter();
    public KafkaExporterSpec buildKafkaExporter();
    public A withKafkaExporter(KafkaExporterSpec kafkaExporter);
    public Boolean hasKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> withNewKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> withNewKafkaExporterLike(KafkaExporterSpec item);
    public KafkaSpecFluent.KafkaExporterNested<A> editKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> editOrNewKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> editOrNewKafkaExporterLike(KafkaExporterSpec item);
    
/**
 * This method has been deprecated, please use method buildClientsCa instead.
 * @return The buildable object.
 */
@Deprecated public CertificateAuthority getClientsCa();
    public CertificateAuthority buildClientsCa();
    public A withClientsCa(CertificateAuthority clientsCa);
    public Boolean hasClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> withNewClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> withNewClientsCaLike(CertificateAuthority item);
    public KafkaSpecFluent.ClientsCaNested<A> editClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> editOrNewClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> editOrNewClientsCaLike(CertificateAuthority item);
    public A addToMaintenanceTimeWindows(int index,String item);
    public A setToMaintenanceTimeWindows(int index,String item);
    public A addToMaintenanceTimeWindows(String... items);
    public A addAllToMaintenanceTimeWindows(Collection<String> items);
    public A removeFromMaintenanceTimeWindows(String... items);
    public A removeAllFromMaintenanceTimeWindows(Collection<String> items);
    public List<String> getMaintenanceTimeWindows();
    public String getMaintenanceTimeWindow(int index);
    public String getFirstMaintenanceTimeWindow();
    public String getLastMaintenanceTimeWindow();
    public String getMatchingMaintenanceTimeWindow(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingMaintenanceTimeWindow(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withMaintenanceTimeWindows(List<String> maintenanceTimeWindows);
    public A withMaintenanceTimeWindows(String... maintenanceTimeWindows);
    public Boolean hasMaintenanceTimeWindows();
    public A addNewMaintenanceTimeWindow(String arg1);
    public A addNewMaintenanceTimeWindow(StringBuilder arg1);
    public A addNewMaintenanceTimeWindow(StringBuffer arg1);

    public interface KafkaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaClusterSpecFluent<KafkaSpecFluent.KafkaNested<N>>{

        
    public N and();    public N endKafka();
}
    public interface ZookeeperNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ZookeeperClusterSpecFluent<KafkaSpecFluent.ZookeeperNested<N>>{

        
    public N and();    public N endZookeeper();
}
    public interface TopicOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TopicOperatorSpecFluent<KafkaSpecFluent.TopicOperatorNested<N>>{

        
    public N and();    public N endTopicOperator();
}
    public interface EntityOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityOperatorSpecFluent<KafkaSpecFluent.EntityOperatorNested<N>>{

        
    public N and();    public N endEntityOperator();
}
    public interface ClusterCaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CertificateAuthorityFluent<KafkaSpecFluent.ClusterCaNested<N>>{

        
    public N and();    public N endClusterCa();
}
    public interface KafkaExporterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaExporterSpecFluent<KafkaSpecFluent.KafkaExporterNested<N>>{

        
    public N and();    public N endKafkaExporter();
}
    public interface ClientsCaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CertificateAuthorityFluent<KafkaSpecFluent.ClientsCaNested<N>>{

        
    public N and();    public N endClientsCa();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/KafkaSpecFluent.java <==
package io.strimzi.api.kafka.model;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.util.Collection;

public interface KafkaSpecFluent<A extends KafkaSpecFluent<A>> extends SpecFluent<A>{


    
/**
 * This method has been deprecated, please use method buildKafka instead.
 * @return The buildable object.
 */
@Deprecated public KafkaClusterSpec getKafka();
    public KafkaClusterSpec buildKafka();
    public A withKafka(KafkaClusterSpec kafka);
    public Boolean hasKafka();
    public KafkaSpecFluent.KafkaNested<A> withNewKafka();
    public KafkaSpecFluent.KafkaNested<A> withNewKafkaLike(KafkaClusterSpec item);
    public KafkaSpecFluent.KafkaNested<A> editKafka();
    public KafkaSpecFluent.KafkaNested<A> editOrNewKafka();
    public KafkaSpecFluent.KafkaNested<A> editOrNewKafkaLike(KafkaClusterSpec item);
    
/**
 * This method has been deprecated, please use method buildZookeeper instead.
 * @return The buildable object.
 */
@Deprecated public ZookeeperClusterSpec getZookeeper();
    public ZookeeperClusterSpec buildZookeeper();
    public A withZookeeper(ZookeeperClusterSpec zookeeper);
    public Boolean hasZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> withNewZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> withNewZookeeperLike(ZookeeperClusterSpec item);
    public KafkaSpecFluent.ZookeeperNested<A> editZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> editOrNewZookeeper();
    public KafkaSpecFluent.ZookeeperNested<A> editOrNewZookeeperLike(ZookeeperClusterSpec item);
    
/**
 * This method has been deprecated, please use method buildTopicOperator instead.
 * @return The buildable object.
 */
@Deprecated public TopicOperatorSpec getTopicOperator();
    public TopicOperatorSpec buildTopicOperator();
    public A withTopicOperator(TopicOperatorSpec topicOperator);
    public Boolean hasTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> withNewTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> withNewTopicOperatorLike(TopicOperatorSpec item);
    public KafkaSpecFluent.TopicOperatorNested<A> editTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> editOrNewTopicOperator();
    public KafkaSpecFluent.TopicOperatorNested<A> editOrNewTopicOperatorLike(TopicOperatorSpec item);
    
/**
 * This method has been deprecated, please use method buildEntityOperator instead.
 * @return The buildable object.
 */
@Deprecated public EntityOperatorSpec getEntityOperator();
    public EntityOperatorSpec buildEntityOperator();
    public A withEntityOperator(EntityOperatorSpec entityOperator);
    public Boolean hasEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> withNewEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> withNewEntityOperatorLike(EntityOperatorSpec item);
    public KafkaSpecFluent.EntityOperatorNested<A> editEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> editOrNewEntityOperator();
    public KafkaSpecFluent.EntityOperatorNested<A> editOrNewEntityOperatorLike(EntityOperatorSpec item);
    
/**
 * This method has been deprecated, please use method buildClusterCa instead.
 * @return The buildable object.
 */
@Deprecated public CertificateAuthority getClusterCa();
    public CertificateAuthority buildClusterCa();
    public A withClusterCa(CertificateAuthority clusterCa);
    public Boolean hasClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> withNewClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> withNewClusterCaLike(CertificateAuthority item);
    public KafkaSpecFluent.ClusterCaNested<A> editClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> editOrNewClusterCa();
    public KafkaSpecFluent.ClusterCaNested<A> editOrNewClusterCaLike(CertificateAuthority item);
    
/**
 * This method has been deprecated, please use method buildJmxTrans instead.
 * @return The buildable object.
 */
@Deprecated public JmxTransSpec getJmxTrans();
    public JmxTransSpec buildJmxTrans();
    public A withJmxTrans(JmxTransSpec jmxTrans);
    public Boolean hasJmxTrans();
    public KafkaSpecFluent.JmxTransNested<A> withNewJmxTrans();
    public KafkaSpecFluent.JmxTransNested<A> withNewJmxTransLike(JmxTransSpec item);
    public KafkaSpecFluent.JmxTransNested<A> editJmxTrans();
    public KafkaSpecFluent.JmxTransNested<A> editOrNewJmxTrans();
    public KafkaSpecFluent.JmxTransNested<A> editOrNewJmxTransLike(JmxTransSpec item);
    
/**
 * This method has been deprecated, please use method buildKafkaExporter instead.
 * @return The buildable object.
 */
@Deprecated public KafkaExporterSpec getKafkaExporter();
    public KafkaExporterSpec buildKafkaExporter();
    public A withKafkaExporter(KafkaExporterSpec kafkaExporter);
    public Boolean hasKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> withNewKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> withNewKafkaExporterLike(KafkaExporterSpec item);
    public KafkaSpecFluent.KafkaExporterNested<A> editKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> editOrNewKafkaExporter();
    public KafkaSpecFluent.KafkaExporterNested<A> editOrNewKafkaExporterLike(KafkaExporterSpec item);
    
/**
 * This method has been deprecated, please use method buildCruiseControl instead.
 * @return The buildable object.
 */
@Deprecated public CruiseControlSpec getCruiseControl();
    public CruiseControlSpec buildCruiseControl();
    public A withCruiseControl(CruiseControlSpec cruiseControl);
    public Boolean hasCruiseControl();
    public KafkaSpecFluent.CruiseControlNested<A> withNewCruiseControl();
    public KafkaSpecFluent.CruiseControlNested<A> withNewCruiseControlLike(CruiseControlSpec item);
    public KafkaSpecFluent.CruiseControlNested<A> editCruiseControl();
    public KafkaSpecFluent.CruiseControlNested<A> editOrNewCruiseControl();
    public KafkaSpecFluent.CruiseControlNested<A> editOrNewCruiseControlLike(CruiseControlSpec item);
    
/**
 * This method has been deprecated, please use method buildClientsCa instead.
 * @return The buildable object.
 */
@Deprecated public CertificateAuthority getClientsCa();
    public CertificateAuthority buildClientsCa();
    public A withClientsCa(CertificateAuthority clientsCa);
    public Boolean hasClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> withNewClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> withNewClientsCaLike(CertificateAuthority item);
    public KafkaSpecFluent.ClientsCaNested<A> editClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> editOrNewClientsCa();
    public KafkaSpecFluent.ClientsCaNested<A> editOrNewClientsCaLike(CertificateAuthority item);
    public A addToMaintenanceTimeWindows(int index,String item);
    public A setToMaintenanceTimeWindows(int index,String item);
    public A addToMaintenanceTimeWindows(String... items);
    public A addAllToMaintenanceTimeWindows(Collection<String> items);
    public A removeFromMaintenanceTimeWindows(String... items);
    public A removeAllFromMaintenanceTimeWindows(Collection<String> items);
    public java.util.List<String> getMaintenanceTimeWindows();
    public String getMaintenanceTimeWindow(int index);
    public String getFirstMaintenanceTimeWindow();
    public String getLastMaintenanceTimeWindow();
    public String getMatchingMaintenanceTimeWindow(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingMaintenanceTimeWindow(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withMaintenanceTimeWindows(java.util.List<String> maintenanceTimeWindows);
    public A withMaintenanceTimeWindows(String... maintenanceTimeWindows);
    public Boolean hasMaintenanceTimeWindows();
    public A addNewMaintenanceTimeWindow(String arg1);
    public A addNewMaintenanceTimeWindow(StringBuilder arg1);
    public A addNewMaintenanceTimeWindow(StringBuffer arg1);

    public interface KafkaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaClusterSpecFluent<KafkaSpecFluent.KafkaNested<N>>{

        
    public N and();    public N endKafka();
}
    public interface ZookeeperNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ZookeeperClusterSpecFluent<KafkaSpecFluent.ZookeeperNested<N>>{

        
    public N and();    public N endZookeeper();
}
    public interface TopicOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TopicOperatorSpecFluent<KafkaSpecFluent.TopicOperatorNested<N>>{

        
    public N and();    public N endTopicOperator();
}
    public interface EntityOperatorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EntityOperatorSpecFluent<KafkaSpecFluent.EntityOperatorNested<N>>{

        
    public N and();    public N endEntityOperator();
}
    public interface ClusterCaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CertificateAuthorityFluent<KafkaSpecFluent.ClusterCaNested<N>>{

        
    public N and();    public N endClusterCa();
}
    public interface JmxTransNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JmxTransSpecFluent<KafkaSpecFluent.JmxTransNested<N>>{

        
    public N and();    public N endJmxTrans();
}
    public interface KafkaExporterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaExporterSpecFluent<KafkaSpecFluent.KafkaExporterNested<N>>{

        
    public N and();    public N endKafkaExporter();
}
    public interface CruiseControlNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CruiseControlSpecFluent<KafkaSpecFluent.CruiseControlNested<N>>{

        
    public N and();    public N endCruiseControl();
}
    public interface ClientsCaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CertificateAuthorityFluent<KafkaSpecFluent.ClientsCaNested<N>>{

        
    public N and();    public N endClientsCa();
}


}
